extern crate getopts;
use getopts::Options;
use std::env;
use std::process::ExitCode;

fn main() -> ExitCode {
    let args: Vec<String> = env::args().collect();
    
    // Define flags
    let mut opts = Options::new();
    opts.optflag("h", "help", "print this help menu");
    opts.optflag("v", "version", "print version");
    opts.reqopt("t", "type", "type of data/instruction to write", "TYPE");
    opts.reqopt("v", "value", "value to write", "VALUE");
    opts.reqopt("o", "output", "output folder", "FOLDER");

    // Print help and exit (see https://github.com/rust-lang/getopts/pull/109)
    if args.contains(&String::from("-h")) || args.contains(&String::from("--help")) {
        print!("{}", opts.usage(&format!("Usage: {} FILE [options]", &args[0])));
        return ExitCode::SUCCESS;
    }

    if args.contains(&String::from("-v")) || args.contains(&String::from("--version")) {
        print!("{} {}", &args[0], env!("CARGO_PKG_VERSION"));
        return ExitCode::SUCCESS;
    }

    // Parse arguments
    let matches = match opts.parse(&args[1..]) {
        Ok(m) => { m }
        Err(f) => { panic!("{}",f.to_string()) }
    };

    

    ExitCode::SUCCESS
}